@@ -6,7 +6,8 @@ use Lingua::KO::Munja ':all';
 binmode STDOUT, ":utf8";
 my $k = parse_kanjidic ('/home/ben/data/edrdg/kanjidic');
 my @o = kanjidic_order ($k);
-for my $kanji (@o) {
+my $max = 100;
+for my $kanji (@o[0..$max]) {
     my $entry = $k->{$kanji};
     my $korean = $entry->{W};
     if (! $korean) {
